#
# spec file for package veyon
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           veyon
Version:        4.5.2
Release:        bp153.1.13
Summary:        Free and Open Source computer monitoring and classroom management
License:        GPL-2.0-or-later
URL:            https://veyon.io/
Source:         https://github.com/veyon/veyon/releases/download/v%{version}/veyon-%{version}-src.tar.bz2
BuildRequires:  cmake
BuildRequires:  cyrus-sasl-devel
BuildRequires:  gcc-c++
BuildRequires:  git
BuildRequires:  hicolor-icon-theme
BuildRequires:  libXcomposite-devel
BuildRequires:  libXcursor-devel
BuildRequires:  libXdamage-devel
BuildRequires:  libXfixes-devel
BuildRequires:  libfakekey-devel
BuildRequires:  libgsasl
BuildRequires:  libjpeg8-devel
BuildRequires:  libpng16-compat-devel
BuildRequires:  libpng16-devel
BuildRequires:  libqca-qt5-plugins
BuildRequires:  openldap2-devel
BuildRequires:  pam-devel
BuildRequires:  pkgconfig
BuildRequires:  procps-devel
BuildRequires:  update-desktop-files
BuildRequires:  xorg-x11-devel
BuildRequires:  cmake(Qt5LinguistTools)
BuildRequires:  pkgconfig(Qt5Concurrent)
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5DBus)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5QuickControls2)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(Qt5X11Extras)
BuildRequires:  pkgconfig(Qt5Xml)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(libfakekey)
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(libprocps)
BuildRequires:  pkgconfig(libsasl2)
BuildRequires:  pkgconfig(libvncclient)
BuildRequires:  pkgconfig(libvncserver)
BuildRequires:  pkgconfig(lzo2)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(polkit-agent-1)
BuildRequires:  pkgconfig(qca2-qt5)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xinerama)
BuildRequires:  pkgconfig(xkbcommon)
BuildRequires:  pkgconfig(xkbcommon-x11)
BuildRequires:  pkgconfig(xp)
BuildRequires:  pkgconfig(xrandr)
BuildRequires:  pkgconfig(xtst)
BuildRequires:  pkgconfig(zlib)
Requires(post): permissions
%{?systemd_requires}

%description
Veyon is a free and Open Source software for computer monitoring and classroom
management supporting Windows and Linux. It enables teachers to view and
control computer labs and interact with students. Veyon is available in
different languages and provides lots of useful features:

* see what's going on in computer labs in overview mode and take screenshots
* remote control computers to support and help users
* broadcast teacher's screen to students in realtime by using demo mode
  (either in fullscreen or in a window)
* lock workstations for attracting attention to teacher
* send text messages to students
* powering on/off and rebooting computers remote
* remote logoff and remote execution of arbitrary commands/scripts
* home schooling - Veyon's network technology is not restricted to a subnet
  and therefore students at home can join lessons via VPN connections just
  by installing the Veyon service

%prep
%setup -q

%build
# explicitly enable PIC code and disable COTIRE precompiled headers since they
# somehow break PIC. MINIMUM_NUMBER_OF_TARGET_SOURCES workaround was the only
# I found to disable this without patching.
%cmake  -DCMAKE_INSTALL_LIBDIR:PATH=%{_lib} \
        -DSYSTEMD_SERVICE_INSTALL_DIR:PATH=%{_unitdir} \
        -DCMAKE_VEYON_X11VNC_EXTERNAL:BOOL=ON \
        -DCMAKE_POSITION_INDEPENDENT_CODE=ON \
        -DCOTIRE_MINIMUM_NUMBER_OF_TARGET_SOURCES=9999 \
	. ../

%cmake_build

%install
%cmake_install
%suse_update_desktop_file -r -G 'Remote desktop software' veyon-master Network RemoteAccess
%suse_update_desktop_file -r -G 'Remote desktop software' veyon-configurator Network RemoteAccess
mkdir -p %{buildroot}%{_sbindir}
pushd %{buildroot}%{_sbindir}
ln -s %{_sbindir}/service rcveyon
popd

%verifyscript
%verify_permissions -e %{_bindir}/veyon-auth-helper

%pre
%service_add_pre veyon.service

%post
%service_add_post veyon.service
%if 0%{?set_permissions:1}
    %set_permissions %{_bindir}/veyon-auth-helper
%else
    %run_permissions
%endif

%preun
%service_del_preun veyon.service

%postun
%service_del_postun veyon.service

%files
%doc README*
%license COPYING
%{_bindir}/veyon-cli
%{_bindir}/veyon-configurator
%{_bindir}/veyon-master
%{_bindir}/veyon-server
%{_bindir}/veyon-service
%{_bindir}/veyon-worker
%verify(not user group mode) %attr(0711,root,root) %{_bindir}/veyon-auth-helper
%{_sbindir}/rcveyon
%{_libdir}/veyon/
%{_datadir}/applications/veyon-master.desktop
%{_datadir}/applications/veyon-configurator.desktop
%{_datadir}/pixmaps/veyon-*.xpm
%{_datadir}/polkit-1/actions/io.veyon.veyon-configurator.policy
%{_datadir}/icons/hicolor/*/apps/veyon*
%{_datadir}/veyon/
%{_unitdir}/veyon.service

%changelog
* Fri Dec 11 2020 andy great <andythe_great@pm.me>
- Update to version 4.5.2.
  * Core: add support for building with ninja
  * LDAP: update 3rdparty component kldap
  * LDAP: add warning on invalid location groups
  * Linux: update 3rdparty component x11vnc to fix CVE-2020-29074
  * Linux: debug server crashes using catchsegv
  * Linux: forward server log messages to system journal
  * RemoteAccess: add option to show window on the same screen as
    the master window
  * RemoteAccess: use non-deprecated API call to fix build with
    Qt >= 5.15.2
  * WebAPI: add Python client implementation + tests
* Wed Nov 25 2020 andy great <andythe_great@pm.me>
- Update to version 4.5.1.
  * Core: fix key name conversion for arguments when invoking
    features
  * Master: properly reload screenshot list also when using
    screenshot directories on network shares
  * Master: add support for deleting multiple screenshots
  * Master: fix bug with initial computer icon layout
  * Master: update icon sizes and their aspect ratios dynamically
    whenever a computer is added, connected or removed
  * Master: improve icon size auto adjust functionality when
    adding/removing multiple computers
  * Master: add dedicated icon for computers not running the Veyon
    Server
  * Master: only show connected computers in slideshow panel
  * Master: fix issue with icons overlapping user name and/or
    computer name
  * Screenshot: fix non-working feature invocation
  * Server: notify first successful access control pass only
- Remove group tag.
* Wed Nov 18 2020 andy great <andythe_great@pm.me>
- Update to version 4.5.0.
  * Core: improve invocation of worker processes for better
    reliability
  * Core: improve message exchange with worker processes
    (fixes demo mode not starting properly in some cases)
  * Core: implement session ID management to reuse a session ID
    after a session has been closed - RDP session IDs (which are
    increased continuously) are no longer used for calculating
    server port numbers
  * Core: rename configuration key Service/PrimaryServicePort to
    Service/VeyonServerPort
  * Core: refactor feature plugin API
  * Configurator: Service: improve session mode configuration UI
  * Configurator: Service: improve network configuration UI
  * Configurator: Master: add option to hide own session
  * Configurator: Master: add computer icon spacing setting
  * Configurator: Master: add computer icon aspect ratio setting
  * Demo: refactor server to be multithreaded which greatly
    improves performance and responsiveness especially with many
    clients
  * Demo: add feature to share a user's screen instead of the own
    one
  * Demo: reset access token after stopping server
  * Demo: refactor modes (window/fullscreen) as subfeatures
    displayed in a drop down menu
  * Demo: add feature to share only one of multiple (own) screens
  * FileTransfer: add configuration page allowing to configure
    source and destination folders
  * Linux: ignore SIGPIPE and continue running normally if a socket
    is closed unexpectedly
  * Linux: fix missing dependencies in Ubuntu 20.04 package
  * Linux: fix and prefer reboot/poweroff via systemd-logind
  * Linux: fix reboot/poweroff if e.g. /sbin or /usr/sbin is not
    in PATH
  * Linux: don't show output of internal systemctl calls
  * Linux: add Debian-gdm as display manager user to properly
    detect that no user is being logged in
  * Linux: Service: retry server start for sessions in opening
    state
  * Linux: Service: manually set environment variable
    XDG_SESSION_ID if pam-systemd is not used
  * Linux: Service: start server instances for active/online
    sessions only - fixes various issues regarding server start on
    user login
  * Master: add Slideshow panel
  * Master: add Spotlight panel
  * Master: always adjust the size of computer icons automatically
    when enabled
  * Master: save and restore states and sizes of panels
  * Master: automatically adjust aspect ratio of computer icons to
    the original screen sizes
  * Master: update already visible tooltips for computer icons
  * Master: make computer icon spacing configurable and decrease
    its default value
  * RemoteAccess: show username in window title
  * RemoteAccess: hide toolbar on focus loss
  * ScreenLock: fix lock widget not being shown and thus screen not
    being locked on some Linux desktops
  * Server: also notify about authentication failure on incomplete
    authentication attempts
  * Server: add support for external VNC servers without any
    authentication/password configured
  * Server: improve error handling for VNC server plugins
  * WebAPI: add new plugin offering a RESTful API for accessing
    Veyon Server instances
* Tue Sep  1 2020 andy great <andythe_great@pm.me>
- Update to version 4.4.2.
  * Core: extend NetworkObject API for future use by add-ons
  * Core: prepare support for future WebAPI plugin
  * Update translations
* Sat Jul 18 2020 andy great <andythe_great@pm.me>
- Update to version 4.4.1.
  * Core: improve multi session support
  * Core: improve worker execution and fix tray icon not being
    shown on startup
  * Demo: broadcast actual teacher session instead of console
    session when running Master within RDP session
  * LDAP: fix computer query on host name lookup error
  * Linux: don't use functions marked deprecated in Qt 5.15
  * Linux: provide package for openSUSE 15.2
  * NetworkObjects: update existing objects instead of adding
    duplicate objects when importing CSV / text file
  * NetworkObjects: output proper line endings when exporting to
    CSV / text file on Windows
  * Server: fix crash on connection accept error
  * Update translations
* Fri Jun 12 2020 andy great <andythe_great@pm.me>
- Update to version 4.4.0.
  * Core: use updated VNC and network stack (libvncserver 0.9.13.)
  * Core: make VNC connection parameters configurable internally
  * Core: improve VNC connection reliability
  * Core: add safe mechanism for opening files preventing symlink
    attacks
  * Core: drop log messages exceeding size limit
  * DesktopServices: improve URL handler invocation (fixes opening
    URLs with characters such as "=")
  * RemoteAccess: honor feature configuration (hide view only
    button when corresponding feature is disabled)
  * Fix possible symlink attacks on log files
  * Update translations
* Mon Jun  8 2020 Matthias Gerstner <matthias.gerstner@suse.com>
- make all executables correctly position-independent.
* Wed May 27 2020 andy great <andythe_great@pm.me>
- Fix veyon not starting: error while loading shared libraries.
* Tue May 12 2020 andy great <andythe_great@pm.me>
- Update to version 4.3.5.
  * Fix: LDAP: make SSL/LDAPS connections work properls (previously
    broken due to improper certificate verifications)
  * Fix: LDAP: enable additional low-level debug messages at the
    command line via environment variable VEYON_DEBUG_LDAP_LIBRARY
  * Update 3rdparty component libvncserver to latest 0.9.13
    snapshot (including new unified connection timeout handling
    support)
  * Master: limit update interval to 10 seconds to prevent server
    timeouts
  * Fix build with Qt >= 5.14
  * Minor code modernizations
  * Update translations
* Mon Nov 18 2019 malcolmlewis@opensuse.org
- Clean up building.
* Wed Jan 17 2018 lars@linux-schulserver.de
- initial version 4.0.3
